==> hubzero-cms_20121015.5.orig.tar.gz: hubzero-cms-20121015.5/cms/components/com_resources/views/view/tmpl/video.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 * All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );
?>

<div id="video-container">
	<?php if(count($this->videos) > 0) : ?>
		<video controls="controls" id="video-player">
			<?php foreach($this->videos as $v) : ?>
				<?php
					$info = pathinfo($v);
					$type = "";
					switch( $info['extension'] )
					{
						case 'mp4': 	$type = 'video/mp4; codecs="avc1.42E01E, mp4a.40.2"';	break;
						case 'ogv':		$type = 'video/ogg; codecs="theora, vorbis"';			break;
						case 'webm':	$type = 'video/webm; codecs="vp8, vorbis"';				break;
					}
				?>
				<source src="<?php echo $this->path . DS . $v; ?>" type="<?php echo $type; ?>" />
			<?php endforeach; ?>
		
			<a href="<?php echo $this->path . DS . $this->video_mp4[0]; ?>" id="video-flowplayer" style="<?php echo "width:{$this->width}px;height:{$this->height}px;"; ?>"></a>
		
			<?php if(count($this->subs) > 0) : ?>
				<?php foreach($this->subs as $s) : ?>
					<?php $info2 = pathinfo($s); ?>
					<div data-type="subtitle" data-lang="<?php echo $info2['filename']; ?>" data-src="<?php echo $this->path . DS . $s; ?>"></div>
				<?php endforeach; ?>
			<?php endif; ?>
		</video>
	<?php endif; ?>   
</div><!-- /#video-container -->

==> hubzero-cms_20130628.2.orig.tar.gz: hubzero-cms-20130628.2/cms/components/com_resources/views/view/tmpl/video.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 * All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );
?>

<div id="video-container">
	<?php if(count($this->videos) > 0) : ?>
		<video controls="controls" id="video-player">
			<?php foreach($this->videos as $v) : ?>
				<?php
					$info = pathinfo($v);
					$type = "";
					switch( $info['extension'] )
					{
						case 'mp4': 	$type = 'video/mp4; codecs="avc1.42E01E, mp4a.40.2"';	break;
						case 'ogv':		$type = 'video/ogg; codecs="theora, vorbis"';			break;
						case 'webm':	$type = 'video/webm; codecs="vp8, vorbis"';				break;
					}
				?>
				<source src="<?php echo $this->path . DS . $v; ?>" type="<?php echo $type; ?>" />
			<?php endforeach; ?>
		
			<a href="<?php echo $this->path . DS . $this->mp4[0]; ?>" id="video-flowplayer" style="<?php echo "width:{$this->width}px;height:{$this->height}px;"; ?>"></a>
		
			<?php if(count($this->subs) > 0) : ?>
				<?php foreach($this->subs as $s) : ?>
					<?php $info2 = pathinfo($s); ?>
					<div data-type="subtitle" data-lang="<?php echo $info2['filename']; ?>" data-src="<?php echo $this->path . DS . $s; ?>"></div>
				<?php endforeach; ?>
			<?php endif; ?>
		</video>
	<?php endif; ?>   
</div><!-- /#video-container -->
